@@ -27,8 +27,7 @@ def login_loader(userid):
 @login_manager.request_loader
 def apikey_loader(request):
     api_key = request.values.get('apikey')
-    if api_key and request.method == 'GET' and \
-            (request.is_json or request.is_xml):
+    if api_key and request.method == 'GET':
         api_key = api_key.replace(',', '=')
         try:
             api_key = urlsafe_b64decode(api_key.encode('utf-8'))
